/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useState, useEffect} from 'react';
import styled from 'styled-components'
import { apiUrl } from "../env";
import  axios from "axios";
import mapaBrasil from '../img/mapa-brasil-line-icon.svg';
import Grid from '@material-ui/core/Grid';

export default function (props) {
    const [available_resources, setAvailableResources] = useState(0)
    const [month_publications, setMonthPublications] = useState(0)
    const [month_downloads, setMonthDownloads] = useState(0)

    useEffect(() => {
        axios.get(`${apiUrl}/statistics`)
        .then(
            (res) => {
                setAvailableResources(res.data.count)
                setMonthPublications(res.data.month_publications)
                setMonthDownloads(res.data.month_downloads)
        })
    }, [])

    return (
        <StatsTab>
            <StyledGrid container>
                <Grid item md={6} xs={12} className="first">
                    <img src={mapaBrasil} height="83px" alt="mapa do brasil"/>
                    <span className="total">
                        <span className="numeros">
                            {available_resources}
                        </span>
                        <span className="legenda">
                            Recursos disponíveis
                        </span>
                    </span>
                </Grid>

                <Grid item md={6} xs={12} className="second">
                    <span className="title">
                        ESSE MÊS:
                    </span> &nbsp;
                    <span className="enviados">
                        <span className="numeros">
                            {month_downloads}
                        </span>

                        <span className="legenda">
                            Baixados
                        </span>
                    </span>
                    <span className="enviados">
                        <span className="numeros">
                            {month_publications}
                        </span>

                        <span className="legenda">
                            Publicados
                        </span>
                    </span>

                </Grid>
            </StyledGrid>
        </StatsTab>
    )

}

const StatsTab = styled.div`
    padding : 20px 0;
    color : #fff;
    background-color : #00bcd4;
`

const StyledGrid = styled(Grid)`
    vertical-align : middle !important;

    .first {
        display : flex !important;
        @media screen and (max-width : 502px) {
            justify-content : center !important;
            border-bottom : 1px dotted #fff !important;
            padding-bottom : 10px !important;
        }
        @media screen and (min-width : 502px) {
            justify-content : right !important;
            text-align : right !important;
            border-right : 1px dotted #fff !important;
        }

        img {
            height : 70px;
        }

    }

    .total {
        text-align : center;
        display : inline-block;
        line-height : 1;
        padding : 0 20px;
    }

    .numeros {
        display : block;
        font-weight : 700;
        font-size : 2.1em;
    }

    .legenda {
        @media screen and (min-width : 502px) {
            font-size : 1.285em;
        }
        font-weight : 300;
    }

    .title {
        @media screen and (min-width : 502px) {
            font-size : 1.42em;
        }
        line-height : 1;
    }

    .enviados {
        text-align : center;
        display : inline-block;
        line-height : 1;
        padding : 0 20px;
    }

    .second {
        @media screen and (min-width : 502px) {
            padding-left : 20px;
        }
        @media screen and (max-width : 502px) {
            justify-content : center !important;
            text-align : center !important;
            padding-top : 10px !important;
            font-size : 16px;
        }
    }

`
